@@ -142,12 +142,16 @@ static void
 impl_Bonobo_ControlFrame_queueResize (PortableServer_Servant  servant,
 				      CORBA_Environment      *ev)
 {
-	/*
-	 * Nothing.
-	 *
-	 * In the Gnome implementation of Bonobo, all size negotiation
-	 * is handled by GtkPlug/GtkSocket for us.
-	 */
+	/* Supposedly Gtk+ handles size negotiation properly for us */
+/*	BonoboSocket *socket;
+	BonoboControlFrame *frame;
+
+	frame = BONOBO_CONTROL_FRAME (bonobo_object (servant));
+
+	if ((socket = frame->priv->socket)) {
+		GTK_SOCKET (socket)->have_size = FALSE;
+		gtk_widget_queue_resize (GTK_WIDGET (socket));
+		} */
 }
 
 static void
@@ -879,6 +883,7 @@ bonobo_control_frame_get_control_property_bag (BonoboControlFrame *frame,
 
 	control = frame->priv->control;
 
+	/* FIXME: we could cache this here - is it called a lot ? */
 	pbag = Bonobo_Control_getProperties (control, real_ev);
 
 	if (BONOBO_EX (real_ev)) {
